AttrBench: Metrics for Feature Attribution Techniques
======================================================
**AttrBench** is a [Pytorch](https://pytorch.org/)-based implementation of several metrics for the evaluation of feature attribution maps and methods.
